==> kubernetes-model-batch-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/batch/CronJobListFluent.java <==
package io.fabric8.kubernetes.api.model.batch;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CronJobListFluent<A extends CronJobListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,CronJob item);
    public A setToItems(int index,CronJob item);
    public A addToItems(CronJob... items);
    public A addAllToItems(Collection<CronJob> items);
    public A removeFromItems(CronJob... items);
    public A removeAllFromItems(Collection<CronJob> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<CronJobBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<CronJob> getItems();
    public List<CronJob> buildItems();
    public CronJob buildItem(int index);
    public CronJob buildFirstItem();
    public CronJob buildLastItem();
    public CronJob buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<CronJobBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<CronJobBuilder> predicate);
    public A withItems(List<CronJob> items);
    public A withItems(CronJob... items);
    public Boolean hasItems();
    public CronJobListFluent.ItemsNested<A> addNewItem();
    public CronJobListFluent.ItemsNested<A> addNewItemLike(CronJob item);
    public CronJobListFluent.ItemsNested<A> setNewItemLike(int index,CronJob item);
    public CronJobListFluent.ItemsNested<A> editItem(int index);
    public CronJobListFluent.ItemsNested<A> editFirstItem();
    public CronJobListFluent.ItemsNested<A> editLastItem();
    public CronJobListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<CronJobBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CronJobFluent<CronJobListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}

==> kubernetes-model-batch-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/batch/CronJobListFluent.java <==
package io.fabric8.kubernetes.api.model.batch;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CronJobListFluent<A extends CronJobListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,CronJob item);
    public A setToItems(int index,CronJob item);
    public A addToItems(CronJob... items);
    public A addAllToItems(Collection<CronJob> items);
    public A removeFromItems(CronJob... items);
    public A removeAllFromItems(Collection<CronJob> items);
    public A removeMatchingFromItems(Predicate<CronJobBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<CronJob> getItems();
    public List<CronJob> buildItems();
    public CronJob buildItem(int index);
    public CronJob buildFirstItem();
    public CronJob buildLastItem();
    public CronJob buildMatchingItem(Predicate<CronJobBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<CronJobBuilder> predicate);
    public A withItems(List<CronJob> items);
    public A withItems(CronJob... items);
    public Boolean hasItems();
    public CronJobListFluent.ItemsNested<A> addNewItem();
    public CronJobListFluent.ItemsNested<A> addNewItemLike(CronJob item);
    public CronJobListFluent.ItemsNested<A> setNewItemLike(int index,CronJob item);
    public CronJobListFluent.ItemsNested<A> editItem(int index);
    public CronJobListFluent.ItemsNested<A> editFirstItem();
    public CronJobListFluent.ItemsNested<A> editLastItem();
    public CronJobListFluent.ItemsNested<A> editMatchingItem(Predicate<CronJobBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CronJobFluent<CronJobListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
